@@ -831,27 +831,29 @@ class Database:
         dfs = {}
         sn = self.sn
         for EM, n, m in sorted(convs.keys()):
-            se = pd.Series(
+            se = pd.DataFrame(
                 [
-                    sn,
-                    self.shape,
-                    self.size,
-                    self.size2,
-                    self.core,
-                    self.clad,
-                    self.wl_max,
-                    self.wl_min,
-                    self.wl_imag,
-                    self.dw,
-                    self.num_n,
-                    self.num_m,
-                    EM,
-                    n,
-                    m,
+                    [
+                        sn,
+                        self.shape,
+                        self.size,
+                        self.size2,
+                        self.core,
+                        self.clad,
+                        self.wl_max,
+                        self.wl_min,
+                        self.wl_imag,
+                        self.dw,
+                        self.num_n,
+                        self.num_m,
+                        EM,
+                        n,
+                        m,
+                    ]
                 ],
-                index=self.catalog_columns.keys(),
+                columns=self.catalog_columns.keys(),
             )
-            catalog = catalog.append(se, ignore_index=True)
+            catalog = pd.concat([catalog, se], axis=0, ignore_index=True)
             conv = convs[(EM, n, m)].ravel()
             beta = betas[(EM, n, m)].ravel()
             df = pd.DataFrame(
@@ -924,7 +926,7 @@ class Database:
         wl_max = bounds["wl_max"]
         wl_min = bounds["wl_min"]
         wl_imag = bounds["wl_imag"]
-        v_lim = bounds.get("v_lim", None)
+        v_lim = bounds.get("v_lim", True)
         beta_imag_max = bounds.get("beta_imag_max", 1e7)
         wr_min = 2 * np.pi / wl_max
         wr_max = 2 * np.pi / wl_min
@@ -950,9 +952,11 @@ class Database:
                     alpha = (pol, n, m)
                     conv = convs[alpha][:, ::-1]
                     vr = vs[alpha][:, ::-1][i_min : i_max + 1, j_min:].real
-                    if v_lim is None:
+                    if v_lim is True:
                         vi = vs[alpha][:, ::-1][i_min : i_max + 1, j_min:].imag
                         v_ok = np.all(np.abs(vr) > np.abs(vi)) & np.all(vr > 0.0)
+                    elif v_lim is False:
+                        v_ok = np.all(True)
                     else:
                         v_ok = np.all(vr > v_lim)
                     if np.all(conv[i_min : i_max + 1, j_min:]) and v_ok:
